using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Orders;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class RecurringProfileRepository : IRecurringProfileRepository
    {
        #region Private

        private const string RepositoryName = "RecurringProfileRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetOrderItemIDByReferenceIDSignature = "GetOrderItemIDByReferenceID";
        private const string GetRecurringIDFromReferenceIDSignature = "GetRecurringIDFromReferenceID";

        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( new string[] { "RecurringProfile", "OrderItem" } );

        private RecurringProfileRepositoryNoCache _repository = new RecurringProfileRepositoryNoCache();

        #endregion

        #region Constructors

        public RecurringProfileRepository()
        {
        }

        public RecurringProfileRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public RecurringProfile Save( RecurringProfile recurringProfile )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            RecurringProfile newRecurringProfile = _repository.Save( recurringProfile );
            _dataCache.ClearRepositoryCache();
            return newRecurringProfile;
        }

        public RecurringProfile GetOne( string recurringID )
        {
            RecurringProfile result = (RecurringProfile) _dataCache.GetValue(
                GetOneSignature,
                _cacheDependency,
                recurringID );

            if (result == null)
            {
                result = _repository.GetOne( recurringID );
                _dataCache.SetValue( GetOneSignature, result, recurringID );
            }

            return result;
        }

        public string GetOrderItemIDByReferenceID( string referenceID )
        {
            object result = _dataCache.GetValue( GetOrderItemIDByReferenceIDSignature, _cacheDependency, referenceID );

            if (result == null)
            {
                result = _repository.GetOrderItemIDByReferenceID( referenceID );
            }

            return result.ToString();
        }

        public void Delete( string recurringID )
        {
            _repository.Delete( recurringID );
            _dataCache.ClearRepositoryCache();
        }

        public string GetRecurringIDFromReferenceID( string referenceID )
        {
            object result = _dataCache.GetValue( GetRecurringIDFromReferenceIDSignature, _cacheDependency, referenceID );

            if (result == null)
            {
                result = _repository.GetRecurringIDFromReferenceID( referenceID );
                _dataCache.SetValue( GetRecurringIDFromReferenceIDSignature, result, referenceID );
            }

            return result.ToString();
        }

        #endregion
    }
}
