using System;
using System.Collections.Generic;
using System.Text;

using Vevo.Domain.Base;
using Vevo.Base.Domain;

namespace Vevo.Domain.Discounts
{
    public class DiscountGroup
    {
        #region Enum

        public enum DiscountTypeEnum
        {
            Percentage,
            Price
        }

        #endregion


        #region Private

        private string _discountGroupID = "0";
        private string _groupName;
        private DiscountTypeEnum _discountType;
        private bool _productOptionDiscount;

        //------------------------------------------------------------
        // Custom private members

        private IEntityList<DiscountRule> _discountRules;


        private class DiscountRuleComparer : IComparer<DiscountRule>
        {
            public int Compare( DiscountRule x, DiscountRule y )
            {
                return x.ToItems.CompareTo( y.ToItems );
            }
        }

        private DiscountRule SelectRule( int quantity )
        {
            List<DiscountRule> sortedRules = new List<DiscountRule>( DiscountRules );
            sortedRules.Sort( new DiscountRuleComparer() );

            foreach (DiscountRule discountRule in sortedRules)
            {
                if (quantity <= discountRule.ToItems)
                    return discountRule;
            }

            return null;
        }

        private decimal CalculatePercentDiscount( double percent, decimal subtotal )
        {
            return subtotal * (decimal) (percent / 100);
        }

        private decimal CalcuateFixedDiscount( decimal fixedDiscountPerItem, int quantity )
        {
            return fixedDiscountPerItem * quantity;
        }

        #endregion


        #region Public Properties

        public string DiscountGroupID
        {
            get { return _discountGroupID; }
            set { _discountGroupID = value; }
        }

        public string GroupName
        {
            get { return _groupName; }
            set { _groupName = value; }
        }

        public DiscountTypeEnum DiscountType
        {
            get { return _discountType; }
            set { _discountType = value; }
        }

        public bool ProductOptionDiscount
        {
            get { return _productOptionDiscount; }
            set { _productOptionDiscount = value; }
        }

        // Return null object
        public static DiscountGroup Null
        {
            get { return NullDiscountGroup.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        #endregion


        #region Custom Properties

        public IEntityList<DiscountRule> DiscountRules
        {
            get
            {
                if (_discountRules == null)
                    _discountRules = new EntityList<DiscountRule>(
                        DataAccessContext.DiscountGroupRepository.GetDiscountRulesByDiscountGroupID( DiscountGroupID ) );

                return _discountRules;
            }
        }

        #endregion


        #region Public Methods

        public static bool HasDiscountRule( string discountGroupID )
        {
            DiscountGroup discountGroup = DataAccessContext.DiscountGroupRepository.GetOne( discountGroupID );
            if (!discountGroup.IsNull
                && discountGroup.DiscountRules.Count > 0)
                return true;
            else
                return false;
        }

        public virtual decimal GetDiscount( int quantity, decimal subtotal )
        {
            DiscountRule discountRule = SelectRule( quantity );

            if (discountRule != null)
            {
                decimal discount;

                if (DiscountType == DiscountGroup.DiscountTypeEnum.Percentage)
                    discount = CalculatePercentDiscount( discountRule.Percentage, subtotal );
                else
                    discount = CalcuateFixedDiscount( discountRule.Amount, quantity );

                if (discount > subtotal)
                    return subtotal;
                else
                    return discount;
            }
            else
            {
                return 0;
            }
        }

        #endregion

    }

}
