using System.Collections.Generic;
using System.IO;
using Vevo.Domain.Users;
using Vevo.Shared.Utilities;
using System.Web.Security;
using Vevo.Base.Domain;
using System.Text;

namespace Vevo.Domain.ImportExport
{
    public class CustomerExporter
    {
        private string GenerateHeader()
        {
            return "\"RegisterDate\"\t\"UserName\"\t\"FirstName\"\t\"LastName\"\t\"Company\"\t\"Address1\"\t" +
                    "\"Address2\"\t\"City\"\t\"State\"\t\"Zip\"\t\"Country\"\t\"Phone\"\t\"Fax\"\t\"Email\"\t" +
                    "\"UseBillingAsShipping\"\t\"ShippingFirstName\"\t\"ShippingLastName\"\t\"ShippingCompany\"\t\"ShippingAddress1\"\t" +
                    "\"ShippingAddress2\"\t\"ShippingCity\"\t\"ShippingState\"\t\"ShippingZip\"\t\"ShippingCountry\"\t\"ShippingPhone\"\t" +
                    "\"ShippingFax\"\t\"ShippingResidential\"\t\"MerchantNotes\"\t\"IsWholesale\"\t\"WholesaleLevel\"\t\"AffiliateCode\"\t" +
                    "\"AffiliateExpireDate\"\t\"IsEnabled\"\t" +
                    "\"IsTaxExempt\"\t\"QBListID\"\t\"IsQBExported\"\t\"ProductIDsCompareList\"\t\"TaxExemptID\"\t\"TaxExemptCountry\"\t\"TaxExemptState\"\t\"FBUserID\"";
        }

        private string GenerateShippingAddressHeader()
        {
            return "\"UserName\"\t\"AliasName\"\t\"ShippingFirstName\"\t\"ShippingLastName\"\t\"ShippingCompany\"\t\"ShippingAddress1\"\t\"ShippingAddress2\"\t" +
                   "\"ShippingCity\"\t\"ShippingState\"\t\"ShippingZip\"\t\"ShippingCountry\"\t\"ShippingPhone\"\t\"ShippingFax\"\t\"ShippingResidential\"\t\"IsSameAsBillingAddress\"";
        }

        private string GenerateDetail( Customer customer )
        {
            string registerDate, userName, firstName, lastName, company, address1, address2;
            string city, state, zip, country, phone, fax, email, userBillingAsShipping, shippingFirstName, shippingLastName;
            string shippingCompany, shippingAddress1, shippingAddress2, shippingCity, shippingState, shippingZip, shippingCountry;
            string shippingPhone, shippingFax, shippingResidential, merchantNotes, isWholesale, wholesaleLevel, affiliateCode;
            string affiliateExpireDate, isEnabled;
            string isTaxExempt, qbListID, isQBExported, productIDsCompareList, taxExemptID, taxExemptCountry, taxExemptState, fbUserID;

            registerDate = ConvertUtilities.ToString( customer.RegisterDate );
            userName = customer.UserName;
            firstName = customer.BillingAddress.FirstName;
            lastName = customer.BillingAddress.LastName;
            company = customer.BillingAddress.Company;
            address1 = customer.BillingAddress.Address1;
            address2 = customer.BillingAddress.Address2;
            city = customer.BillingAddress.City;
            state = customer.BillingAddress.State;
            zip = customer.BillingAddress.Zip;
            country = customer.BillingAddress.Country;
            phone = customer.BillingAddress.Phone;
            fax = customer.BillingAddress.Fax;
            email = customer.Email;
            userBillingAsShipping = ConvertUtilities.ToString( customer.UseBillingAsShipping );
            shippingFirstName = customer.ShippingAddress.FirstName;
            shippingLastName = customer.ShippingAddress.LastName;
            shippingCompany = customer.ShippingAddress.Company;
            shippingAddress1 = customer.ShippingAddress.Address1;
            shippingAddress2 = customer.ShippingAddress.Address2;
            shippingCity = customer.ShippingAddress.City;
            shippingState = customer.ShippingAddress.State;
            shippingZip = customer.ShippingAddress.Zip;
            shippingCountry = customer.ShippingAddress.Country;
            shippingPhone = customer.ShippingAddress.Phone;
            shippingFax = customer.ShippingAddress.Fax;
            shippingResidential = ConvertUtilities.ToString( customer.ShippingAddress.Residential );
            merchantNotes = customer.MerchantNotes;
            isWholesale = ConvertUtilities.ToString( customer.IsWholesale );
            wholesaleLevel = ConvertUtilities.ToString( customer.WholesaleLevel );
            affiliateCode = customer.AffiliateCode;
            affiliateExpireDate = ConvertUtilities.ToString( customer.AffiliateExpireDate );
            isEnabled = ConvertUtilities.ToString( customer.IsEnabled );
            isTaxExempt = ConvertUtilities.ToString( customer.IsTaxExempt );
            qbListID = customer.QBListID;
            isQBExported = ConvertUtilities.ToString( customer.IsQBExported );
            productIDsCompareList = customer.ProductIDsCompareList;
            taxExemptID = customer.TaxExemptID;
            taxExemptCountry = customer.TaxExemptCountry;
            taxExemptState = customer.TaxExemptState;
            fbUserID = customer.FBUserID;

            return registerDate + "\t" + userName + "\t" + firstName + "\t" + lastName + "\t" + company + "\t" +
                address1 + "\t" + address2 + "\t" + city + "\t" + state + "\t" + zip + "\t" + country + "\t" + phone + "\t" + fax + "\t" +
                email + "\t" + userBillingAsShipping + "\t" + shippingFirstName + "\t" + shippingLastName + "\t" + shippingCompany + "\t" +
                shippingAddress1 + "\t" + shippingAddress2 + "\t" + shippingCity + "\t" + shippingState + "\t" + shippingZip + "\t" +
                shippingCountry + "\t" + shippingPhone + "\t" + shippingFax + "\t" + shippingResidential + "\t" + merchantNotes + "\t" +
                isWholesale + "\t" + wholesaleLevel + "\t" + affiliateCode + "\t" + affiliateExpireDate + "\t" + isEnabled + "\t" +
                isTaxExempt + "\t" + qbListID + "\t" + isQBExported + "\t" + productIDsCompareList + "\t" + taxExemptID + "\t" +
                taxExemptCountry + "\t" + taxExemptState + "\t" + fbUserID;
        }

        private string GenerateShippingAddressDetail( ShippingAddress address )
        {
            string userName, aliasName, shippingFirstName, shippingLastName, shippingCompany, shippingAddress1;
            string shippingAddress2, shippingCity, shippingState, shippingZip, shippingCountry, shippingPhone;
            string shippingFax, shippingResidential, isSameAsBillingAddress;

            userName = DataAccessContext.CustomerRepository.GetOne( address.CustomerID ).UserName;
            aliasName = address.AliasName;
            shippingFirstName = address.FirstName;
            shippingLastName = address.LastName;
            shippingCompany = address.Company;
            shippingAddress1 = address.Address1;
            shippingAddress2 = address.Address2;
            shippingCity = address.City;
            shippingState = address.State;
            shippingZip = address.Zip;
            shippingCountry = address.Country;
            shippingPhone = address.Phone;
            shippingFax = address.Fax;
            shippingResidential = ConvertUtilities.ToString( address.Residential );
            isSameAsBillingAddress = ConvertUtilities.ToString( address.IsSameAsBillingAddress );

            return userName + "\t" + aliasName + "\t" + shippingFirstName + "\t" + shippingLastName + "\t" + shippingCompany + "\t" +
                shippingAddress1 + "\t" + shippingAddress2 + "\t" + shippingCity + "\t" + shippingState + "\t" +
                shippingZip + "\t" + shippingCountry + "\t" + shippingPhone + "\t" + shippingFax + "\t" + shippingResidential + "\t" + isSameAsBillingAddress;
        }

        public MemoryStream ExportToStream( IList<Customer> customersList )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream, Encoding.Unicode );

            if (customersList.Count > 0)
            {
                sw.WriteLine( GenerateHeader() );
                string details;
                foreach (Customer customer in customersList)
                {
                    details = GenerateDetail( customer );
                    sw.WriteLine( details );
                }
            }


            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }

        public MemoryStream ExportShippingAddressToStream( IList<ShippingAddress> addressList )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream, Encoding.Unicode );

            if (addressList.Count > 0)
            {
                sw.WriteLine( GenerateShippingAddressHeader() );
                string details;
                foreach (ShippingAddress address in addressList)
                {
                    details = GenerateShippingAddressDetail( address );
                    sw.WriteLine( details );
                }
            }


            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }

    }
}
