﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.WebAppLib;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain;
using System.Data;
using Vevo.Domain.Discounts;
using Vevo.Base.Domain;

namespace Vevo.WebServices.Coupons
{
    public class CouponService : ICouponService
    {
        private CouponConstraints ConvertCouponToConstraints( Coupon coupon )
        {
            CouponConstraints constraints = new CouponConstraints();
            constraints.CategoryIDs = coupon.CategoryIDs;
            constraints.CouponID = coupon.CouponID;
            constraints.CurrentQuantity = coupon.CurrentQuantity;
            constraints.CustomerFilter = coupon.CustomerFilter;
            constraints.CustomerUserName = coupon.CustomerUserName;
            constraints.DiscountAmount = coupon.DiscountAmount;
            constraints.DiscountType = coupon.DiscountType;
            constraints.ExpirationDate = coupon.ExpirationDate;
            constraints.ExpirationQuantity = coupon.ExpirationQuantity;
            constraints.ExpirationType = coupon.ExpirationType;
            constraints.FreeShippingType = coupon.FreeShippingType;
            constraints.MerchantNotes = coupon.MerchantNotes;
            constraints.MinimumQuantity = coupon.MinimumQuantity;
            constraints.MinimumSubtotal = coupon.MinimumSubtotal;
            constraints.Percentage = coupon.Percentage;
            constraints.ProductCostType = coupon.ProductCostType;
            constraints.ProductFilter = coupon.ProductFilter;
            constraints.ProductIDs = coupon.ProductIDs;
            constraints.PromotionQuantity = coupon.PromotionQuantity;
            constraints.RepeatDiscount = coupon.RepeatDiscount;

            return constraints;
        }

        public CouponListResponseMessage ListCoupons( CouponListRequestMessage ListMessage )
        {
            CouponListResponseMessage responseMessage = new CouponListResponseMessage();
            if ( WcfSessionPool.GetSession( ListMessage.Ticket ) == null )
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter(
                                ListMessage.SearchFilter );
                int couponCount = 0;
                IList<Coupon> coupon_result = DataAccessContext.CouponRepository.SearchCoupon( "CouponID", searchFilter, ListMessage.SearchFilter.StartIndex, ListMessage.SearchFilter.EndIndex, out couponCount );
                responseMessage.Coupons = new List<CouponConstraints>();
                foreach ( Coupon coupon in coupon_result )
                {
                    responseMessage.Coupons.Add( ConvertCouponToConstraints( coupon ) );
                }
            }
            catch ( Exception e )
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get coupons from repository";
            }

            return responseMessage;
        }
    }
}
