﻿using System;
using System.Collections.Generic;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.ImportExport;
using Vevo.Domain.Products;
using Vevo.WebAppLib;
using Vevo.WebServices.Base;
using Vevo.WebServices.Cultures;
using Vevo.WebServices.SearchFilters;
using Vevo.WebServices.Security;
using Vevo.Base.Domain;
using Vevo.Deluxe.Domain.Products;
using Vevo.Deluxe.Domain;

namespace Vevo.WebServices.Products
{
    public class ProductService : IProductService
    {
        #region Private
        private Culture ConvertConstraintToCulture( CultureConstraints cultureConstraints )
        {
            Culture culture = new Culture();
            culture.CultureID = cultureConstraints.CultureID;
            culture.DisplayName = cultureConstraints.Display;
            culture.Enabled = cultureConstraints.Enabled;
            culture.Name = cultureConstraints.Name;
            return culture;
        }

        private CultureConstraints ConvertCultureToConstraint( Culture culture )
        {
            CultureConstraints cultureConstraints = new CultureConstraints();
            cultureConstraints.CultureID = culture.CultureID;
            cultureConstraints.Display = culture.DisplayName;
            cultureConstraints.Enabled = culture.Enabled;
            cultureConstraints.Name = culture.Name;
            return cultureConstraints;
        }

        private ProductConstraints ConvertProductToConstraints( Product product, string storeID, string cultureID )
        {
            ProductConstraints productConstraints = new ProductConstraints();
            productConstraints.ProductID = product.ProductID;
            productConstraints.SKU = product.Sku;
            productConstraints.DiscountGroupID = product.DiscountGroupID;
            productConstraints.Name = product.Name;
            productConstraints.ShortDescription = product.ShortDescription;
            productConstraints.LongDescription = product.LongDescription;
            productConstraints.Model = product.Model;
            productConstraints.Weight = product.Weight;
            productConstraints.FixedShippingCost = product.FixedShippingCost;
            productConstraints.ShippingCost = product.ShippingCost;
            productConstraints.Manufacturer = product.Manufacturer;
            productConstraints.Keywords = product.Keywords;
            productConstraints.Other1 = product.Other1;
            productConstraints.Other2 = product.Other2;
            productConstraints.Other3 = product.Other3;
            productConstraints.Other4 = product.Other4;
            productConstraints.Other5 = product.Other5;
            productConstraints.IsTodaySpecial = product.IsTodaySpecial;
            productConstraints.IsDownloadable = product.IsDownloadable;
            productConstraints.DownloadPath = product.DownloadPath;
            productConstraints.IsEnabled = product.IsEnabled;
            productConstraints.RelatedProducts = product.RelatedProducts;
            productConstraints.MerchantRating = product.MerchantRating;
            productConstraints.IsFixedPrice = product.IsFixedPrice;
            productConstraints.ManufacturerPartNumber = product.ManufacturerPartNumber;
            productConstraints.Upc = product.Upc;
            productConstraints.TaxClassID = product.TaxClassID;
            productConstraints.UseInventory = product.UseInventory;
            productConstraints.IsRecurring = product.IsRecurring;
            productConstraints.IsAffiliate = product.IsAffiliate;
            productConstraints.MinQuantity = product.MinQuantity;
            productConstraints.MaxQuantity = product.MaxQuantity;
            productConstraints.FreeShippingCost = product.FreeShippingCost;
            productConstraints.IsCustomPrice = product.IsCustomPrice;
            productConstraints.IsCallForPrice = product.IsCallForPrice;
            productConstraints.Brand = product.Brand;
            productConstraints.CategoryIDs = new List<string>( product.CategoryIDs );
            productConstraints.DepartmentIDs = new List<string>( product.DepartmentIDs );
            productConstraints.ReturnTime = product.ReturnTime;
            productConstraints.IsProductKit = product.IsProductKit;
            productConstraints.IsDynamicProductKitPrice = product.IsDynamicProductKitPrice;
            productConstraints.IsDynamicProductKitWeight = product.IsDynamicProductKitWeight;
            productConstraints.CreateDate = product.CreateDate;
            productConstraints.ViewCount = product.ViewCount;

            foreach (ProductMetaInformation meta in product.GetMetaInformations( storeID ))
            {
                if (meta.CultureID == cultureID)
                {
                    productConstraints.MetaInformation = new ProductMetaInformationConstraints();
                    productConstraints.MetaInformation.CultureID = cultureID;
                    productConstraints.MetaInformation.ProductID = product.ProductID;
                    productConstraints.MetaInformation.StoreID = storeID;
                    productConstraints.MetaInformation.MetaDescription = meta.MetaDescription;
                    productConstraints.MetaInformation.MetaKeyword = meta.MetaKeyword;
                    productConstraints.MetaInformation.UseDefaultMetaDescription = meta.UseDefaultMetaDescription;
                    productConstraints.MetaInformation.UseDefaultMetaKeyword = meta.UseDefaultMetaKeyword;
                }
            }

            ProductPrice productPrice = product.GetProductPrice( storeID );
            productConstraints.ProductPrices = new ProductPriceConstraints();
            productConstraints.ProductPrices.ProductID = product.ProductID;
            productConstraints.ProductPrices.Price = productPrice.Price;
            productConstraints.ProductPrices.RetailPrice = productPrice.RetailPrice;
            productConstraints.ProductPrices.StoreID = storeID;
            productConstraints.ProductPrices.UseDefaultPrice = productPrice.UseDefaultPrice;
            productConstraints.ProductPrices.UseDefaultRetailPrice = productPrice.UseDefaultRetailPrice;
            productConstraints.ProductPrices.UseDefaultWholeSalePrice = productPrice.UseDefaultWholeSalePrice;
            productConstraints.ProductPrices.UseDefaultWholeSalePrice2 = productPrice.UseDefaultWholeSalePrice2;
            productConstraints.ProductPrices.UseDefaultWholeSalePrice3 = productPrice.UseDefaultWholeSalePrice3;
            productConstraints.ProductPrices.WholeSalePrice = productPrice.WholesalePrice;
            productConstraints.ProductPrices.WholeSalePrice2 = productPrice.WholesalePrice2;
            productConstraints.ProductPrices.WholeSalePrice3 = productPrice.WholesalePrice3;

            foreach (ProductShippingCost shippingCost in product.ProductShippingCosts)
            {
                ProductShippingCostConstraints psc = new ProductShippingCostConstraints();
                psc.ProductID = productConstraints.ProductID;
                psc.ShippingID = shippingCost.ShippingID;
                psc.FixedShippingCost = shippingCost.FixedShippingCost;
                if (productConstraints.ProductShippingCosts == null)
                    productConstraints.ProductShippingCosts = new List<ProductShippingCostConstraints>();
                productConstraints.ProductShippingCosts.Add( psc );
            }

            ProductStock productStock = product.FindProductStock();
            if (productStock != null)
            {
                productConstraints.ProductStocks = new ProductStockConstraints();
                productConstraints.ProductStocks.Stock = productStock.Stock;
                productConstraints.ProductStocks.StockEnabled = productStock.StockEnabled;
            }

            if (product.IsRecurring)
            {
                ProductRecurringConstraints productRecurring = new ProductRecurringConstraints();
                productRecurring.RecurringInterval = product.ProductRecurring.RecurringInterval;
                productRecurring.RecurringIntervalUnit = product.ProductRecurring.RecurringIntervalUnit;
                productRecurring.RecurringNumberOfCycles = product.ProductRecurring.RecurringNumberOfCycles;
                productRecurring.RecurringNumberOfTrialCycles = product.ProductRecurring.RecurringNumberOfTrialCycles;
                productRecurring.RecurringTrialAmount = product.ProductRecurring.RecurringTrialAmount;
                if (productConstraints.ProductRecurring == null)
                    productConstraints.ProductRecurring = new ProductRecurringConstraints();
                productConstraints.ProductRecurring = productRecurring;
            }

            if (product.IsCustomPrice)
            {
                ProductCustomPriceConstraints productCustomPrice = new ProductCustomPriceConstraints();
                productCustomPrice.DefaultPrice = product.ProductCustomPrice.DefaultPrice;
                productCustomPrice.MinimumPrice = product.ProductCustomPrice.MinimumPrice;
                productConstraints.ProductCustomPrice = productCustomPrice;
            }

            if ((product.ProductImages != null) && (product.ProductImages.Count != 0))
            {
                ProductImageConstraints productImage = new ProductImageConstraints();
                foreach (ProductImage image in product.ProductImages)
                {
                    productImage.IsEnlarge = image.IsEnlarge;
                    productImage.IsZoom = image.IsZoom;
                    productImage.LargeImage = image.LargeImage;
                    productImage.ProductImageID = image.ProductImageID;
                    productImage.RegularImage = image.RegularImage;
                    productImage.SortOrder = image.SortOrder;
                    productImage.ThumbnailImage = image.ThumbnailImage;
                    productConstraints.ProductImages = new List<ProductImageConstraints>();
                    productConstraints.ProductImages.Add( productImage );
                }
            }

            if (productConstraints.ProductOptionGroups == null)
                productConstraints.ProductOptionGroups = new List<ProductOptionGroupConstraints>();
            foreach (ProductOptionGroup productOptionGroup in product.ProductOptionGroups)
            {
                ProductOptionGroupConstraints pogc = new ProductOptionGroupConstraints();

                pogc.DefaultCulture = ConvertCultureToConstraint( productOptionGroup.DefaultCulture );
                pogc.OptionGroupID = productOptionGroup.OptionGroupID;
                pogc.UseStock = productOptionGroup.UseStock;
                pogc.OptionGroup = new OptionGroupConstraints();
                pogc.OptionGroup.DefaultCulture = ConvertCultureToConstraint( productOptionGroup.OptionGroup.DefaultCulture );
                pogc.OptionGroup.OptionGroupID = productOptionGroup.OptionGroup.OptionGroupID;
                pogc.OptionGroup.Type = productOptionGroup.OptionGroup.Type;

                pogc.OptionGroup.Locales = new List<OptionGroupLocaleConstraints>();
                foreach (OptionGroupLocale optionGroupLocale in productOptionGroup.OptionGroup.Locales)
                {
                    OptionGroupLocaleConstraints optionGroupLocalConstraints = new OptionGroupLocaleConstraints();
                    optionGroupLocalConstraints.CultureID = optionGroupLocale.CultureID;
                    optionGroupLocalConstraints.DisplayText = optionGroupLocale.DisplayText;
                    optionGroupLocalConstraints.Name = optionGroupLocale.Name;
                    pogc.OptionGroup.Locales.Add( optionGroupLocalConstraints );
                }

                pogc.OptionGroup.OptionItems = new List<OptionItemConstraints>();
                foreach (OptionItem optionItem in productOptionGroup.OptionGroup.OptionItems)
                {
                    OptionItemConstraints optionItemConstrants = new OptionItemConstraints();
                    optionItemConstrants.DefaultCulture = ConvertCultureToConstraint( optionItem.DefaultCulture );
                    optionItemConstrants.ImageFile = optionItem.ImageFile;
                    optionItemConstrants.OptionGroupID = optionItem.OptionGroupID;
                    optionItemConstrants.OptionItemID = optionItem.OptionItemID;
                    optionItemConstrants.OptionItemType = optionItem.OptionItemType;
                    optionItemConstrants.PercentageChange = optionItem.PercentageChange;
                    optionItemConstrants.WeightToAdd = optionItem.WeightToAdd;
                    optionItemConstrants.PriceToAdd = optionItem.PriceToAdd;

                    optionItemConstrants.Locales = new List<OptionItemLocaleConstraints>();
                    foreach (OptionItemLocale optionItemLocale in optionItem.Locales)
                    {
                        OptionItemLocaleConstraints optionItemLocaleConstraints = new OptionItemLocaleConstraints();
                        optionItemLocaleConstraints.CultureID = optionItemLocale.CultureID;
                        optionItemLocaleConstraints.Name = optionItemLocale.Name;
                        optionItemConstrants.Locales.Add( optionItemLocaleConstraints );
                    }
                }

                productConstraints.ProductOptionGroups.Add( pogc );
            }

            if (productConstraints.ProductSpecifications == null)
                productConstraints.ProductSpecifications = new List<ProductSpecificationConstraints>();
            foreach (ProductSpecification productSpecification in product.ProductSpecifications)
            {
                ProductSpecificationConstraints psc = new ProductSpecificationConstraints();
                psc.ProductID = productConstraints.ProductID;
                psc.SpecificationItemID = productSpecification.SpecificationItemID;
                psc.Value = productSpecification.Value;


                productConstraints.ProductSpecifications.Add( psc );
            }

            if (productConstraints.ProductSubscriptions == null)
                productConstraints.ProductSubscriptions = new List<ProductSubscriptionConstraints>();

            foreach (ProductSubscription productSubscription in DataAccessContextDeluxe.ProductSubscriptionRepository.GetProductSubscriptions( product.ProductID ))
            {
                ProductSubscriptionConstraints subscription = new ProductSubscriptionConstraints();
                subscription.ProductID = productConstraints.ProductID;
                subscription.SubscriptionLevelID = productSubscription.SubscriptionLevelID;
                subscription.Range = productSubscription.Range;


                productConstraints.ProductSubscriptions.Add( subscription );
            }

            if (productConstraints.ProductKits == null)
                productConstraints.ProductKits = new List<ProductKitConstraints>();

            foreach (ProductKit productKit in product.ProductKits)
            {
                ProductKitConstraints kit = new ProductKitConstraints();
                kit.CultureID = productKit.DefaultCulture.CultureID;
                kit.ProductKitGroupID = productKit.ProductKitGroupID;
                kit.SortOrder = productKit.SortOrder;

                productConstraints.ProductKits.Add( kit );
            }

            return productConstraints;
        }

        private bool SaveProductItem( Product product, ProductConstraints productConstraints, string storeID, Culture culture )
        {
            string discountGroupID = String.IsNullOrEmpty( product.DiscountGroupID )
                ? "0" : product.DiscountGroupID;

            if (productConstraints.Name != null) product.Name = productConstraints.Name;
            if (productConstraints.ShortDescription != null) product.ShortDescription = productConstraints.ShortDescription;
            if (productConstraints.LongDescription != null) product.LongDescription = productConstraints.LongDescription;
            if (productConstraints.SKU != null) product.Sku = productConstraints.SKU;
            if (productConstraints.Brand != null) product.Brand = productConstraints.Brand;
            if (productConstraints.Model != null) product.Model = productConstraints.Model;
            product.Weight = productConstraints.Weight;
            product.FixedShippingCost = productConstraints.FixedShippingCost;
            product.ShippingCost = productConstraints.ShippingCost;
            if (productConstraints.Manufacturer != null) product.Manufacturer = productConstraints.Manufacturer;
            if (productConstraints.Keywords != null) product.Keywords = productConstraints.Keywords;
            if (productConstraints.Other1 != null) product.Other1 = productConstraints.Other1;
            if (productConstraints.Other2 != null) product.Other2 = productConstraints.Other2;
            if (productConstraints.Other3 != null) product.Other3 = productConstraints.Other3;
            if (productConstraints.Other4 != null) product.Other4 = productConstraints.Other4;
            if (productConstraints.Other5 != null) product.Other5 = productConstraints.Other5;
            product.IsTodaySpecial = productConstraints.IsTodaySpecial;
            product.IsDownloadable = productConstraints.IsDownloadable;
            if (productConstraints.DownloadPath != null) product.DownloadPath = productConstraints.DownloadPath;
            product.IsEnabled = productConstraints.IsEnabled;
            if (productConstraints.RelatedProducts != null) product.RelatedProducts = productConstraints.RelatedProducts;
            product.MerchantRating = productConstraints.MerchantRating;
            product.DiscountGroupID = discountGroupID;
            product.IsFixedPrice = productConstraints.IsFixedPrice;
            if (productConstraints.ManufacturerPartNumber != null) product.ManufacturerPartNumber = productConstraints.ManufacturerPartNumber;
            if (productConstraints.Upc != null) product.Upc = productConstraints.Upc;
            if (productConstraints.TaxClassID != null) product.TaxClassID = productConstraints.TaxClassID;
            product.UseInventory = productConstraints.UseInventory;
            product.IsRecurring = productConstraints.IsRecurring;
            product.IsAffiliate = productConstraints.IsAffiliate;
            product.MinQuantity = productConstraints.MinQuantity;
            product.MaxQuantity = productConstraints.MaxQuantity;
            product.FreeShippingCost = productConstraints.FreeShippingCost;
            product.ReturnTime = productConstraints.ReturnTime;
            product.IsProductKit = productConstraints.IsProductKit;
            product.IsDynamicProductKitWeight = productConstraints.IsDynamicProductKitWeight;
            product.IsDynamicProductKitPrice = productConstraints.IsDynamicProductKitPrice;
            product.CreateDate = productConstraints.CreateDate;
            product.ViewCount = productConstraints.ViewCount;

            product.CategoryIDs = new List<string>( productConstraints.CategoryIDs );
            product.DepartmentIDs = new List<string>( productConstraints.DepartmentIDs );

            ProductImporter productImporter = new ProductImporter( culture );

            if (productConstraints.MetaInformation != null)
                product = productImporter.SetProductMetaInformation( product, storeID, productConstraints.MetaInformation.MetaKeyword, productConstraints.MetaInformation.MetaDescription );

            if (productConstraints.ProductPrices != null)
            {
                ProductPrice csvPrice = new ProductPrice();
                csvPrice.Price = productConstraints.ProductPrices.Price;
                csvPrice.RetailPrice = productConstraints.ProductPrices.RetailPrice;
                csvPrice.WholesalePrice = productConstraints.ProductPrices.WholeSalePrice;
                csvPrice.WholesalePrice2 = productConstraints.ProductPrices.WholeSalePrice2;
                csvPrice.WholesalePrice3 = productConstraints.ProductPrices.WholeSalePrice3;
                product = productImporter.SetProductPrice( product, storeID, csvPrice );
            }

            product.ProductShippingCosts.Clear();
            if (productConstraints.ProductShippingCosts != null)
            {
                foreach (ProductShippingCostConstraints shippingCost in productConstraints.ProductShippingCosts)
                {
                    ProductShippingCost psc = new ProductShippingCost();
                    psc.ProductID = productConstraints.ProductID;
                    psc.ShippingID = shippingCost.ShippingID;
                    psc.FixedShippingCost = shippingCost.FixedShippingCost;
                    product.ProductShippingCosts.Add( psc );
                }
            }

            if (productConstraints.ProductStocks != null)
                product.SetStockWithNoOption( productConstraints.ProductStocks.Stock );

            if ((productConstraints.IsRecurring) && (productConstraints.ProductRecurring != null))
            {
                ProductRecurring recurring = new ProductRecurring();
                recurring.RecurringInterval = productConstraints.ProductRecurring.RecurringInterval;
                recurring.RecurringIntervalUnit = productConstraints.ProductRecurring.RecurringIntervalUnit;
                recurring.RecurringNumberOfCycles = productConstraints.ProductRecurring.RecurringNumberOfCycles;
                recurring.RecurringNumberOfTrialCycles = productConstraints.ProductRecurring.RecurringNumberOfTrialCycles;
                recurring.RecurringTrialAmount = productConstraints.ProductRecurring.RecurringTrialAmount;
                product.ProductRecurring = recurring;
            }

            product.ProductImages.Clear();
            if (productConstraints.ProductImages != null)
            {
                foreach (ProductImageConstraints productImage in productConstraints.ProductImages)
                {
                    ProductImage image = new ProductImage();
                    image.RegularImage = productImage.RegularImage;
                    image.LargeImage = productImage.LargeImage;
                    image.ThumbnailImage = productImage.ThumbnailImage;
                    image.IsZoom = productImage.IsZoom;
                    image.IsEnlarge = productImage.IsEnlarge;
                    image.SortOrder = productImage.SortOrder;

                    product.ProductImages.Add( image );
                }
            }

            if (productConstraints.ProductOptionGroups != null)
            {
                foreach (ProductOptionGroupConstraints productOptionGroup in productConstraints.ProductOptionGroups)
                {
                    Culture defaultCulture = ConvertConstraintToCulture( productOptionGroup.DefaultCulture );
                    ProductOptionGroup pog = new ProductOptionGroup( defaultCulture );
                    pog.DefaultCulture = defaultCulture;
                    pog.OptionGroupID = productOptionGroup.OptionGroupID;
                    pog.UseStock = productOptionGroup.UseStock;

                    product.ProductOptionGroups.Add( pog );
                }
            }

            product.ProductSpecifications.Clear();
            if (productConstraints.ProductSpecifications != null)
            {
                foreach (ProductSpecificationConstraints productSpecificationItem in productConstraints.ProductSpecifications)
                {
                    ProductSpecification psc = new ProductSpecification();
                    psc.ProductID = productConstraints.ProductID;
                    psc.SpecificationItemID = productSpecificationItem.SpecificationItemID;
                    psc.Value = productSpecificationItem.Value;

                    product.ProductSpecifications.Add( psc );
                }
            }

            product.ProductKits.Clear();
            if (productConstraints.ProductKits != null)
            {
                foreach (ProductKitConstraints productKitItem in productConstraints.ProductKits)
                {
                    Culture kitCulture = DataAccessContext.CultureRepository.GetOne( productKitItem.CultureID );
                    ProductKit pk = new ProductKit( kitCulture );
                    pk.ProductKitGroupID = productKitItem.ProductKitGroupID;
                    pk.SortOrder = productKitItem.SortOrder;

                    product.ProductKits.Add( pk );
                }
            }

            Product newProd = DataAccessContext.ProductRepository.Save( product );
            DataAccessContext.ProductRepository.RefreshProductUrlNameAll( newProd.Name );

            return true;
        }

        #endregion

        #region Public

        public ProductListResponseMessage ListProducts( ProductListRequestMessage ListMessage )
        {
            ProductListResponseMessage responseMessage = new ProductListResponseMessage();
            if (WcfSessionPool.GetSession( ListMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }

            try
            {
                Culture culture = DataAccessContext.CultureRepository.GetOne( ListMessage.CultureID );
                Vevo.Domain.Products.Category category = DataAccessContext.CategoryRepository.GetOne( culture, ListMessage.CategoryID );
                List<Product> products = new List<Product>();

                int start = ListMessage.SearchFilter.StartIndex;
                int end = ListMessage.SearchFilter.EndIndex;
                int count;
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter(
                                                ListMessage.SearchFilter );
                IList<Product> subproducts = DataAccessContext.ProductRepository.SearchProduct( culture, category.CategoryID, "ProductID", searchFilter, start, end, out count, ListMessage.StoreID, category.RootID );

                responseMessage.Products = new List<ProductConstraints>();
                foreach (Product product in subproducts)
                {
                    responseMessage.Products.Add( ConvertProductToConstraints( product, ListMessage.StoreID, culture.CultureID ) );
                }
            }
            catch (Exception e)
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get product(s) from repository";
            }

            return responseMessage;
        }

        public ResponseMessage AddProducts( ProductSaveRequestMessage AddMessage )
        {
            ResponseMessage responseMessage = new ResponseMessage();
            if (WcfSessionPool.GetSession( AddMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }

            string errorAdd = String.Empty;
            int count = 0;
            Culture culture = DataAccessContext.CultureRepository.GetOne( AddMessage.CultureID );
            foreach (ProductConstraints productConstraints in AddMessage.Products)
            {
                count += 1;
                try
                {
                    bool result = SaveProductItem( new Product( culture ), productConstraints, AddMessage.StoreID, culture );
                    if (!result)
                    {
                        errorAdd += count.ToString() + ",";
                    }
                }
                catch (Exception e)
                {
                    WebUtilities.LogError( e );
                    errorAdd += count.ToString() + ",";
                }
            }
            if (errorAdd.Length > 0)
            {
                errorAdd = errorAdd.Substring( 0, errorAdd.Length - 1 );
                responseMessage.ErrorMessage += "Error: Cannot add product(s) at :" + errorAdd;
            }
            return responseMessage;
        }

        public ResponseMessage UpdateProducts( ProductSaveRequestMessage UpdateMessage )
        {
            ResponseMessage responseMessage = new ResponseMessage();
            if (WcfSessionPool.GetSession( UpdateMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }

            string errorUpdate = String.Empty;
            int count = 0;
            Culture culture = DataAccessContext.CultureRepository.GetOne( UpdateMessage.CultureID );
            foreach (ProductConstraints productConstraints in UpdateMessage.Products)
            {
                count += 1;
                try
                {
                    bool result = false;
                    Product product = DataAccessContext.ProductRepository.GetOne( culture, productConstraints.ProductID, UpdateMessage.StoreID );
                    result = SaveProductItem( product, productConstraints, UpdateMessage.StoreID, culture );
                    if (!result)
                    {
                        errorUpdate += count.ToString() + ",";
                    }
                }
                catch (Exception e)
                {
                    WebUtilities.LogError( e );
                    errorUpdate += count.ToString() + ",";
                }
            }
            if (errorUpdate.Length > 0)
            {
                errorUpdate = errorUpdate.Substring( 0, errorUpdate.Length - 1 );
                responseMessage.ErrorMessage += "Error: Cannot update product(s) at :" + errorUpdate;
            }
            return responseMessage;
        }

        public ResponseMessage DeleteProducts( ProductDeleteRequestMessage DeleteMessage )
        {
            ResponseMessage responseMessage = new ResponseMessage();
            if (WcfSessionPool.GetSession( DeleteMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }

            string errorDelete = String.Empty;
            foreach (string productID in DeleteMessage.ProductID)
            {
                try
                {
                    DataAccessContext.ProductRepository.Delete( productID );
                    DataAccessContextDeluxe.PromotionProductRepository.DeleteByProductID( productID );
                    DataAccessContextDeluxe.ProductSubscriptionRepository.DeleteByProductID( productID );
                }
                catch (Exception e)
                {
                    WebUtilities.LogError( e );
                    errorDelete += productID + ",";
                }
            }

            if (errorDelete.Length > 0)
            {
                errorDelete = errorDelete.Substring( 0, errorDelete.Length - 1 );
                responseMessage.ErrorMessage += "Error: Cannot delete productID(s) :" + errorDelete;
            }
            return responseMessage;
        }


        #endregion
    }

}
