using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using Vevo.Data;
using Vevo.Domain;
using Vevo.Domain.Contents;
using Vevo.WebUI;

namespace Vevo.WebUI.Contents
{
    /// <summary>
    /// Summary description for BaseContentMenuNavListUserControl
    /// </summary>
    public class BaseContentMenuNavListUserControl : Vevo.WebUI.International.BaseLanguageUserControl
    {
        #region Private

        private void PopulateContentMenu( int nodeDepth, MenuItem item, string parentContentMenuID )
        {
            IList<ContentMenuItem> list = DataAccessContext.ContentMenuItemRepository.GetByContentMenuID(
                StoreContext.Culture, parentContentMenuID, "SortOrder", BoolFilter.ShowTrue );

            foreach (ContentMenuItem contentMenuItem in list)
            {
                item.ChildItems.Add( CreateMenuItemWithChildren( nodeDepth, contentMenuItem ) );
            }
        }

        #endregion


        #region Protected

        protected void SetSelectedContentMenuItem(
            MenuItem menuItem,
            string contentMenuItemID,
            string contentMenuItemName )
        {
            if (menuItem.Value == contentMenuItemID || menuItem.Text == contentMenuItemName)
            {
                if (menuItem.Value == ContentMenuItemID || menuItem.Text == ContentMenuItemName)
                    menuItem.Selected = true;
                return;
            }
            else
            {
                foreach (MenuItem mi in menuItem.ChildItems)
                {
                    if (mi.Value == contentMenuItemID || mi.Text == contentMenuItemName)
                    {
                        if (mi.Value == ContentMenuItemID || mi.Text == ContentMenuItemName)
                            mi.Selected = true;
                        SetSelectedContentMenuItem( menuItem, mi.Parent.Value, mi.Parent.Text );

                        return;
                    }

                    SetSelectedContentMenuItem( mi, contentMenuItemID, contentMenuItemName );
                }
            }
        }

        protected MenuItem CreateMenuItemWithChildren( int nodeDepth, ContentMenuItem contentMenuItem )
        {
            MenuItem newItem = new MenuItem();
            newItem.Text = contentMenuItem.Name;
            newItem.Value = contentMenuItem.ContentMenuItemID;
            newItem.ToolTip = contentMenuItem.Description;
            if (contentMenuItem.ReferringMenuID != "0")
            {
                newItem.NavigateUrl = UrlManager.GetContentMenuUrl(
                    contentMenuItem.ContentMenuItemID, contentMenuItem.UrlName );

                if (nodeDepth < MaxNode) //Max Tree depth
                    PopulateContentMenu( nodeDepth + 1, newItem, contentMenuItem.ReferringMenuID );
            }
            else
            {
                Vevo.Domain.Contents.Content content = DataAccessContext.ContentRepository.GetOne(
                    StoreContext.Culture, contentMenuItem.ContentID.ToString() );

                newItem.NavigateUrl = UrlManager.GetContentUrl( content.ContentID, content.UrlName );
            }
            return newItem;
        }

        #endregion

        #region Public
        public string ContentMenuItemID
        {
            get
            {
                if (ViewState["ContentMenuItemID"] == null)
                    return "0";
                return ViewState["ContentMenuItemID"].ToString();
            }
            set
            {
                ViewState["ContentMenuItemID"] = value;
            }
        }


        public string ContentMenuItemName
        {
            get
            {
                if (ViewState["ContentMenuItemName"] == null)
                    return String.Empty;
                return ViewState["ContentMenuItemName"].ToString();
            }
            set
            {
                ViewState["ContentMenuItemName"] = value;
            }
        }

        public int MaxNode
        {
            get
            {
                if (ViewState["MaxNode"] == null)
                    return 0;
                return Convert.ToInt32(ViewState["MaxNode"]);
            }
            set
            {
                ViewState["MaxNode"] = value;
            }
        }
        #endregion
    }
}
