using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Shared.Utilities;

namespace Vevo.WebUI
{
    public class PaymentModuleSetup : ISystemSetup
    {
        #region Private

        private ISystemSetup _paymentAppInitializer;

        private ISystemSetup PaymentAppInitializer
        {
            get
            {
                if (_paymentAppInitializer == null)
                {
                    Type type = Type.GetType(
                        "Vevo.PaymentApp.WebUI.PaymentAppInitializer, Vevo.PaymentApp.WebUI" );

                    if (type != null)
                    {
                        object paymentAppInitializer = Activator.CreateInstance( type );
                        _paymentAppInitializer = (ISystemSetup) paymentAppInitializer;
                    }
                }
                return _paymentAppInitializer;
            }
        }

        #endregion


        #region Public Properties

        public bool IsPaymentModuleIntegrated
        {
            get
            {
                return PaymentAppInitializer != null;
            }
        }

        #endregion


        #region ISystemSetup Members

        public void ProcessApplicationStarted()
        {
            ISystemSetup initializer = PaymentAppInitializer;
            if (initializer != null)
                initializer.ProcessApplicationStarted();
        }

        public void ProcessDatabaseConnected()
        {
            ISystemSetup initializer = PaymentAppInitializer;
            if (initializer != null)
                initializer.ProcessDatabaseConnected();
        }

        public bool EncryptionKeyExists()
        {
            ISystemSetup initializer = PaymentAppInitializer;
            if (initializer != null)
                return initializer.EncryptionKeyExists();
            else
                return true;
        }

        #endregion

    }
}
